@@ -4,7 +4,7 @@ package Ithumb::XS;
 
 =head1 NAME
 
-Ithumb::XS
+Ithumb::XS - small and simple Imlib2 thumbnail module.
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw( create_thumbnail );
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 require XSLoader;
 XSLoader::load('Ithumb::XS', $VERSION);
@@ -60,4 +60,13 @@ Creates a small copy (with cropping) of the image.
   
 =back
 
+=head1 LICENSE
+
+BSD 3-Clause License
+
+Copyright (c) 2018, Peter P. Neuromantic <p.brovchenko@protonmail.com>
+All rights reserved.
+
+See LICENSE file for more details.
+
 =cut
